<!-- SeleniumBase Docs -->

## [<img src="https://seleniumbase.io/img/logo6.png" title="SeleniumBase" width="32">](https://github.com/seleniumbase/SeleniumBase/) Demo Mode 🎦

<p align="left"><img src="https://seleniumbase.github.io/cdn/gif/xkcd_vid.gif" width="400" alt="SeleniumBase Example" title="SeleniumBase Example" /></p>

<p align="left">🔵 <b>Demo Mode</b> helps you see what a test is doing.</p>

<p align="left">🏇💨 👀 If a test runs too fast for your eyes, use <b>Demo Mode</b> to slow it down, highlight actions, and display assertions. Example usage:</p>

```bash
pytest my_first_test.py --demo
```

--------

<p align="left">Here's how to run <a href="https://github.com/seleniumbase/SeleniumBase/blob/master/examples/test_swag_labs.py" target="_blank">test_swag_labs.py</a> from <a href="https://github.com/seleniumbase/SeleniumBase/tree/master/examples" target="_blank">examples/</a> in <b>Demo Mode</b>:</p>


```bash
pytest test_swag_labs.py --demo
```

<p align="left"><a href="https://www.saucedemo.com/" target="_blank"><img src="https://seleniumbase.github.io/cdn/gif/swag_demo_2.gif" width="450" alt="SeleniumBase Example" title="SeleniumBase Example" /></a></p>

--------

<p>Here's an example that only uses the <code>highlight()</code> method for highlighting browser actions:</p>


<p align="left">(<a href="https://github.com/seleniumbase/SeleniumBase/blob/master/examples/test_error_page.py" target="_blank">test_error_page.py</a> from <a href="https://github.com/seleniumbase/SeleniumBase/tree/master/examples" target="_blank">examples/</a>)</p>

```bash
pytest test_error_page.py
```

<p align="left"><a href="https://seleniumbase.io/error_page/" target="_blank"><img src="https://seleniumbase.github.io/cdn/gif/error_page.gif" width="450" alt="SeleniumBase Example" title="SeleniumBase Example" /></a></p>

--------

Here's an example of a mobile test in <b>Demo Mode</b>:

<p align="left"><img src="https://seleniumbase.github.io/cdn/gif/skype_mobile_test_2.gif" width="450" alt="SeleniumBase Example" title="SeleniumBase Example" /></p>
